I made a kernel 2.2x faster. It made my training loop 3x slower

·Hacker News··

I wrote a fused decode-attention kernel for an RL training loop, got it 2.2× faster than the SDPA path it replaces at the microbenchmark level, dropped it in...

Read full article →

Related Articles

Anthropic S-1
SiNTEx · Hacker News · 16h ago
Solar power is becoming bigger than nuclear
geox · Hacker News · 14h ago
The Exponential Time Hypothesis Is False [pdf]
vok · Hacker News · 7h ago
Oldest GUI application that still runs on Windows 11
enlyth · Hacker News · 11h ago
Type Server Protocol
adamnemecek · Hacker News · 11h ago